# Ubiquity

Ubiquity est un logiciel de suivi de TP de développement
informatique. Il permet aux tuteurs d’encadrer facilement et de
manière optimisée un groupe d’étudiants.

Grâce à Ubiquity, l’enseignant crée de façon simple, un TP, en
déposant un sujet et sa correction annotée. Les étudiants
récupèrent ensuite le sujet ainsi que les fichiers sources à compléter.

Ubiquity permet aussi à l’enseignant de suivre en temps réel
l’avancement de chaque étudiant dans la réalisation du TP, grâce
à différents indicateurs. Ainsi, l’enseignant identifie
rapidement les étudiants en difficultés. Ubiquity permet aussi aux
étudiants de se situer, par rapport à l’avancement de leurs
collègues.

Ubiquity est un logiciel **opensource** et **gratuit**, disponible sur
Windows, MacOs et Linux. Il peut s’utiliser aussi bien en
présentiel qu’en distanciel, de manière synchrone ou asynchrone.


Pour plus d'information, nous vous invitons à regarder 
la vidéo de [présentation d'ubiquity](https://webtv.insa-rouen.fr/videos/presentation-de-ubiquity/) 
et à lire le [wiki](https://gitlab.insa-rouen.fr/delestre/ubiquity/-/wikis/home) proposant une documentation fonctionnelle et technique.

## Installation

Pour installer l'application : `pip install ubiquity-student`

## Exécution

Pour exécuter l'application : `ubiquity-student`

## Licence

Distribué sous la License GNU GENERAL PUBLIC LICENSE v3.0. Voir [LICENSE](https://gitlab.insa-rouen.fr/cip/ubiquity/-/blob/master/LICENSE) pour plus d'information.